@@ -78,12 +78,6 @@ class Sherlock:
         self.setup_files(update_ois, update_force, update_clean)
         self.sherlock_targets = sherlock_targets
         self.habitability_calculator = HabitabilityCalculator()
-        self.detrend_plot_axis = [[1, 1], [2, 1], [3, 1], [2, 2], [3, 2], [3, 2], [3, 3], [3, 3], [3, 3], [4, 3],
-                                  [4, 3], [4, 3], [4, 4], [4, 4], [4, 4], [4, 4], [5, 4], [5, 4], [5, 4], [5, 4],
-                                  [6, 4], [6, 4], [6, 4], [6, 4]]
-        self.detrend_plot_axis.append([1, 1])
-        self.detrend_plot_axis.append([2, 1])
-        self.detrend_plot_axis.append([3, 1])
         self.lcbuilder = LcBuilder()
 
     def setup_files(self, refresh_ois, refresh_force, refresh_clean, results_dir=RESULTS_DIR):
@@ -251,6 +245,8 @@ class Sherlock:
                 lc_df['#time'] = time[args]
                 lc_df['flux'] = lc[args]
                 lc_df['flux_err'] = np.array(flux_err[args])
+                flux_err_mean = np.nanmean(lc_df['flux_err'])
+                lc_df.loc[(lc_df['flux_err'] == 0) | np.isnan(lc_df['flux_err']), 'flux_err'] = flux_err_mean
                 lc_df.to_csv(object_dir + "/lc_" + str(i) + ".csv", index=False)
                 i = i + 1
             wl = np.concatenate(([0], wl), axis=0)
@@ -298,8 +294,6 @@ class Sherlock:
                     object_report["transits"] = ""
                 object_report["sectors"] = ','.join(map(str, lc_build.sectors)) \
                     if lc_build.sectors is not None and len(lc_build.sectors) > 0 else None
-                object_report["ffi"] = sherlock_target.object_info.cadence >= 600
-
                 object_report["oi"] = self.__find_matching_oi(sherlock_target.object_info, object_report["period"])
                 if best_signal_score == 1:
                     logging.info('New best signal is good enough to keep searching. Going to the next run.')
@@ -372,6 +366,7 @@ class Sherlock:
         return dir + "/"
 
     def __setup_logging(self):
+        logging.captureWarnings(True)
         formatter = logging.Formatter(fmt='%(asctime)s %(levelname)-8s %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
         logger = logging.getLogger()
         while len(logger.handlers) > 0:
@@ -599,9 +594,10 @@ class Sherlock:
         plot_dir = self.__init_object_dir(object_id) + "/detrends/"
         if not os.path.exists(plot_dir):
             os.mkdir(plot_dir)
-        figsize = (8, 8)  # x,y
-        rows = self.detrend_plot_axis[detrends_number - 1][0]
-        cols = self.detrend_plot_axis[detrends_number - 1][1]
+        figsize = (12, 4 * detrends_number)  # x,y
+        rows = detrends_number
+        cols = 1
+        min_original = np.min(original_lc[low_index:high_index])
         shift = 2 * (1.0 - (np.min(original_lc)))  # shift in the between the raw and detrended data
         fig, axs = plt.subplots(rows, cols, figsize=figsize, constrained_layout=True)
         if detrends_number > 1:
@@ -612,15 +608,16 @@ class Sherlock:
         original_lc_partial = original_lc[low_index:high_index]
         for flatten_lc_detrended, lc_trend, bin_centers, bin_means, flatten_wl in flatten_results:
             lc_trend_partial = lc_trend[low_index:high_index]
+            dist = 1.3 * ((1 - min_original) + (np.max(flatten_lc_detrended) - 1))
             if detrends_number > 1:
                 plot_axs = axs[i]
             if detrend_method == 'gp':
                 plot_axs.set_title('ks=%s' % str(np.around(flatten_wl, decimals=4)))
             else:
                 plot_axs.set_title('ws=%s d' % str(np.around(flatten_wl, decimals=4)))
-            plot_axs.plot(time_partial[1:], original_lc_partial[1:], linewidth=0.05, color='black', alpha=0.75,
-                          rasterized=True)
-            plot_axs.plot(time_partial[1:], lc_trend_partial[1:], linewidth=1, color='orange', alpha=1.0)
+            plot_axs.scatter(time_partial[1:], original_lc_partial[1:], color='black', s=1, alpha=0.25, rasterized=True)
+            plot_axs.plot(time_partial[1:], lc_trend_partial[1:], linewidth=2, color='firebrick', alpha=1.)
+            plot_axs.scatter(time_partial[1:], flatten_lc_detrended[low_index:high_index][1:] - dist, color='black', s=1, alpha=0.75, rasterized=True)
             plot_axs.set_ylabel("Flux norm.")
             plot_axs.set_xlabel("Time (d)")
             i = i + 1
